@@ -134,7 +134,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 self.slots.append(Ui_Slot(slot))
 
             self.quit.clicked.connect(self.quitHook)
-            self.help.clicked.connect(self.helpHook)
+            #self.help.clicked.connect(self.helpHook)
         except Exception as error:
             print(error)
             
