@@ -8,12 +8,15 @@ import threading
 import ntpath
 import os
 
+if __name__ == "__main__":
+    import sys, os, inspect
+    currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
+    parentdir = os.path.dirname(currentdir)
+    sys.path.insert(0, parentdir)
 
-#sys.path.append('/home/pi/gxf/python/spotii')
-from spotii.define import *
-#sys.path.append('/home/pi/gxf/python/spotii/test_handler')
 
-from .calibration import crop_rotate
+from define import *
+from test_handler.calibration import crop_rotate
 
 
 def camInstCreate(cameraIndex):
